@@ -14,9 +14,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 # -------------------------------------------------------------------------
@@ -36,6 +35,15 @@ _ = glocale.translation.gettext
 from .. import Rule
 
 
+# -------------------------------------------------------------------------
+#
+# Typing modules
+#
+# -------------------------------------------------------------------------
+from ....lib import Person
+from ....db import Database
+
+
 # -------------------------------------------------------------------------
 # "People with less than 2 parents"
 # -------------------------------------------------------------------------
@@ -50,15 +58,15 @@ class MissingParent(Rule):
     )
     category = _("Family filters")
 
-    def apply(self, db, person):
-        families = person.get_parent_family_handle_list()
+    def apply_to_one(self, db: Database, person: Person) -> bool:
+        families = person.parent_family_list
         if families == []:
             return True
-        for family_handle in person.get_parent_family_handle_list():
+        for family_handle in families:
             family = db.get_family_from_handle(family_handle)
             if family:
-                father_handle = family.get_father_handle()
-                mother_handle = family.get_mother_handle()
+                father_handle = family.father_handle
+                mother_handle = family.mother_handle
                 if not father_handle:
                     return True
                 if not mother_handle:
