@@ -16,9 +16,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -30,17 +29,17 @@ Location class for Gramps.
 # Gramps modules
 #
 # -------------------------------------------------------------------------
-from .secondaryobj import SecondaryObject
-from .locationbase import LocationBase
-from .const import IDENTICAL, DIFFERENT
 from ..const import GRAMPS_LOCALE as glocale
+from .const import DIFFERENT, IDENTICAL
+from .locationbase import LocationBase
+from .secondaryobj import SecondaryObject
 
 _ = glocale.translation.gettext
 
 
 # -------------------------------------------------------------------------
 #
-# Location class for Places
+# Location
 #
 # -------------------------------------------------------------------------
 class Location(SecondaryObject, LocationBase):
@@ -121,8 +120,7 @@ class Location(SecondaryObject, LocationBase):
         """
         if self.is_equal(other):
             return IDENTICAL
-        else:
-            return DIFFERENT
+        return DIFFERENT
 
     def merge(self, acquisition):
         """
@@ -133,9 +131,9 @@ class Location(SecondaryObject, LocationBase):
         :param acquisition: The location to merge with the present location.
         :type acquisition: Location
         """
-        pass
 
     def is_empty(self):
+        """Return true if empty."""
         return (
             not self.street
             and not self.locality
