@@ -16,9 +16,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 """
 GrampsLocale encapsulates localization and locale
@@ -526,7 +525,7 @@ class GrampsLocale:
                 translator.lang = lang
                 return translator
 
-            if lang.startswith("en") or lang.startswith("C"):
+            if lang.startswith(("en", "C")):
                 translator = GrampsNullTranslations()
                 translator.lang = "en"
                 return translator
