@@ -15,12 +15,11 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
-""" This contains the main class corresponding to a running gramps process """
+"""This contains the main class corresponding to a running gramps process"""
 
 # -------------------------------------------------------------------------
 #
@@ -215,7 +214,7 @@ UIDEFAULT = (
           <attribute name="label" translatable="yes">F_ull Screen</attribute>
         </item>
       </section>
-      <section id="ViewsInCatagory">
+      <section id="ViewsInCategory">
       </section>
     </submenu>
     <submenu id="m5" groups='RO'>
@@ -573,7 +572,12 @@ class Gramps:
         dbstate = DbState()
         self._vm = ViewManager(app, dbstate, config.get("interface.view-categories"))
 
-        if lin() and glocale.lang != "C" and not gettext.find(GTK_GETTEXT_DOMAIN):
+        if (
+            lin()
+            and "SNAP" not in os.environ
+            and glocale.lang != "C"
+            and not gettext.find(GTK_GETTEXT_DOMAIN)
+        ):
             _display_gtk_gettext_message(parent=self._vm.window)
 
         _display_translator_message(parent=self._vm.window)
