@@ -19,9 +19,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -695,6 +694,7 @@ class GuiPersonOption(Gtk.Box):
         """
         # Create a filter for the person selector.
         rfilter = GenericFilter()
+        rfilter.set_name(_("Active, bookmarked or home people"))
         rfilter.set_logical_op("or")
         rfilter.add_rule(rules.person.IsBookmarked([]))
         rfilter.add_rule(rules.person.HasIdOf([self.__option.get_value()]))
@@ -718,7 +718,7 @@ class GuiPersonOption(Gtk.Box):
             self.__uistate,
             self.__track,
             title=_("Select a person for the report"),
-            filter=rfilter,
+            search_or_filter=rfilter,
         )
         person = sel.run()
         self.__update_person(person)
@@ -852,6 +852,8 @@ class GuiFamilyOption(Gtk.Box):
         """
         # Create a filter for the person selector.
         rfilter = GenericFilterFactory("Family")()
+        rfilter.set_name(_("Active or bookmarked families"))
+
         rfilter.set_logical_op("or")
 
         # Add the current family
@@ -881,7 +883,9 @@ class GuiFamilyOption(Gtk.Box):
         # rfilter.add_rule(rules.family.HasIdOf([gid]))
 
         select_class = SelectorFactory("Family")
-        sel = select_class(self.__dbstate, self.__uistate, self.__track, filter=rfilter)
+        sel = select_class(
+            self.__dbstate, self.__uistate, self.__track, search_or_filter=rfilter
+        )
         family = sel.run()
         if family:
             self.__update_family(family.get_handle())
