@@ -17,12 +17,11 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
-""" GUI dialog for creating and managing books """
+"""GUI dialog for creating and managing books"""
 
 # Written by Alex Roitman,
 # largely based on the BaseDoc classes by Don Allingham
@@ -1029,7 +1028,7 @@ class BookDialog(DocReportDialog):
         selected_style = StyleSheet()
 
         pstyle = self.paper_frame.get_paper_style()
-        self.doc = self.format(None, pstyle)
+        self.doc = self.format(None, pstyle, uistate=self.uistate)
 
         for item in self.book.get_item_list():
             item.option_class.set_document(self.doc)
