@@ -15,9 +15,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -787,8 +786,13 @@ class ListView(NavigationView):
         if not self.search_bar.is_visible():
             filter_info = (True, self.generic_filter, False)
         else:
-            value = self.search_bar.get_value()
-            filter_info = (False, value, value[0] in self.exact_search())
+            filter_info = self.search_bar.get_value()
+            if not filter_info[0]:
+                filter_info = (
+                    filter_info[0],
+                    filter_info[1],
+                    filter_info[1][0] in self.exact_search(),
+                )
 
         if same_col:
             # activate when https://bugzilla.gnome.org/show_bug.cgi?id=684558
