@@ -23,9 +23,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """LaTeX document generator"""
@@ -35,6 +34,7 @@
 # Python modules
 #
 # ------------------------------------------------------------------------
+from __future__ import annotations
 from bisect import bisect
 import re
 import os
@@ -615,7 +615,8 @@ class LaTeXBackend(DocBackend):
         DocBackend.STRIKETHROUGH: ("\\sout{", "}"),
     }
 
-    ESCAPE_FUNC = lambda x: latexescape
+    def ESCAPE_FUNC(x):
+        return latexescape
 
     def setescape(self, preformatted=False):
         """
@@ -627,7 +628,7 @@ class LaTeXBackend(DocBackend):
         else:
             LaTeXBackend.ESCAPE_FUNC = lambda x: latexescapeverbatim
 
-    def _create_xmltag(self, type, value):
+    def _create_xmltag(self, tagtype, value):
         r"""
         overwrites the method in DocBackend.
         creates the latex tags needed for non bool style types we support:
@@ -636,9 +637,9 @@ class LaTeXBackend(DocBackend):
                                      : very basic, in mono in the font face
                                         then we use {\ttfamily }
         """
-        if type not in self.SUPPORTED_MARKUP:
+        if tagtype not in self.SUPPORTED_MARKUP:
             return None
-        elif type == DocBackend.FONTSIZE:
+        elif tagtype == DocBackend.FONTSIZE:
             # translate size in point to something LaTeX can work with
             fontsize = map_font_size(value)
             if fontsize:
@@ -646,7 +647,7 @@ class LaTeXBackend(DocBackend):
             else:
                 return ("", "")
 
-        elif type == DocBackend.FONTFACE:
+        elif tagtype == DocBackend.FONTFACE:
             if "MONO" in value.upper():
                 return ("{\\ttfamily ", "}")
             elif "ROMAN" in value.upper():
@@ -701,7 +702,7 @@ class LaTeXDoc(BaseDoc, TextDoc):
     pict_in_table = False
     pict_width = 0
     pict_height = 0
-    textmem = []
+    textmem: list[str] = []
     in_title = True
 
     #   ---------------------------------------------------------------
