@@ -17,9 +17,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -27,6 +26,9 @@ Reports/Graphical Reports/Familial Tree
 Reports/Graphical Reports/Personal Tree
 """
 
+from __future__ import annotations
+from typing import Any
+
 # ------------------------------------------------------------------------
 #
 # Gramps modules
@@ -1251,7 +1253,7 @@ class GuiConnect:
       get the value from a GUI variable
     """
 
-    __shared_state = {}
+    __shared_state: dict[str, Any] = {}
 
     def __init__(self):  # We are BORG!
         self.__dict__ = self.__shared_state
