@@ -20,9 +20,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 "Export to GEDCOM"
@@ -98,6 +97,7 @@ LDS_ORD_NAME = {
     LdsOrd.SEAL_TO_PARENTS: "SLGC",
     LdsOrd.SEAL_TO_SPOUSE: "SLGS",
     LdsOrd.CONFIRMATION: "CONL",
+    LdsOrd.INITIATORY: "INIL",
 }
 
 LDS_STATUS = {
