@@ -20,13 +20,11 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
-"""Report output generator based on Cairo.
-"""
+"""Report output generator based on Cairo."""
 
 # ------------------------------------------------------------------------
 #
@@ -34,6 +32,7 @@
 #
 # ------------------------------------------------------------------------
 
+from __future__ import annotations
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 
 _ = glocale.translation.gettext
@@ -312,7 +311,7 @@ class GtkDocBaseElement:
     """
 
     _type = "BASE"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     def __init__(self, style=None):
         self._parent = None
@@ -444,7 +443,7 @@ class GtkDocPagebreak(GtkDocBaseElement):
     """Implement a page break."""
 
     _type = "PAGEBREAK"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     def divide(self, layout, width, height, dpi_x, dpi_y):
         return (None, None), 0
@@ -454,7 +453,7 @@ class GtkDocTableOfContents(GtkDocBaseElement):
     """Implement a table of contents."""
 
     _type = "TOC"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     def divide(self, layout, width, height, dpi_x, dpi_y):
         return (self, None), 0
@@ -467,7 +466,7 @@ class GtkDocAlphabeticalIndex(GtkDocBaseElement):
     """Implement an alphabetical index."""
 
     _type = "INDEX"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     def divide(self, layout, width, height, dpi_x, dpi_y):
         return (self, None), 0
@@ -480,7 +479,7 @@ class GtkDocParagraph(GtkDocBaseElement):
     """Paragraph."""
 
     _type = "PARAGRAPH"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     # line spacing is not defined in ParagraphStyle
     spacingfractionfont = 0.2
@@ -1076,7 +1075,7 @@ class GtkDocPicture(GtkDocBaseElement):
     """Implement an image."""
 
     _type = "IMAGE"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     def __init__(self, style, filename, width, height, crop=None):
         GtkDocBaseElement.__init__(self, style)
@@ -1207,7 +1206,7 @@ class GtkDocLine(GtkDocBaseElement):
     """Implement a line."""
 
     _type = "LINE"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     def __init__(self, style, x1, y1, x2, y2):
         GtkDocBaseElement.__init__(self, style)
@@ -1238,7 +1237,7 @@ class GtkDocPolygon(GtkDocBaseElement):
     """Implement a line."""
 
     _type = "POLYGON"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     def __init__(self, style, path):
         GtkDocBaseElement.__init__(self, style)
@@ -1273,7 +1272,7 @@ class GtkDocBox(GtkDocBaseElement):
     """Implement a box with optional shadow around it."""
 
     _type = "BOX"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     def __init__(self, style, x, y, width, height):
         GtkDocBaseElement.__init__(self, style)
@@ -1323,7 +1322,7 @@ class GtkDocText(GtkDocBaseElement):
     """Implement a text on graphical reports."""
 
     _type = "TEXT"
-    _allowed_children = []
+    _allowed_children: list[str] = []
 
     # line spacing is not defined in ParagraphStyle
     spacingfractionfont = 0.2
