@@ -27,9 +27,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, see <https://www.gnu.org/licenses/>.
 #
 
 """
@@ -758,9 +757,10 @@ class PersonPages(BasePage):
                     individualdetail += sect14
 
             # display source references
-            sect14 = self.display_ind_sources(person)
-            if sect14 is not None:
-                individualdetail += sect14
+            if report.options["inc_sources"]:
+                sect14 = self.display_ind_sources(person)
+                if sect14 is not None:
+                    individualdetail += sect14
 
         # add clearline for proper styling
         # create footer section
